local AnimationController = class {
	init = function(self,anims,state)
		self.anims = {}
		self.state = state or ""
		self.frame = ""
		
		for i,v in pairs(anims) do
			self.anims[i] = {
				playing = false,
				anim = Animation.load(v),
			}
		end
	end,
	
	update = function(self,dt)
		if self.anims[self.state] then
			if self.anims[self.state].playing then
				self.anims[self.state].anim.update(dt)
				self.frame = self.anims[self.state].anim.getCurrent()
			end
		end
	end,
	
	getCurrentFrame = function(self)
		return self.frame
	end,
	
	playAnimation = function(self,name)
		self:stopAllAnimations()
		self.state = name
		self.anims[name].playing = true
	end,
	
	stopAnimation = function(self,name)
		self.anims[name].playing = false
		self.anims[name].anim.time = 0
	end,
	
	stopAllAnimations = function(self)
		for i,v in pairs(self.anims) do
			self:stopAnimation(i)
		end
		
		self.state = ""
	end,
	
	setLooping = function(self,name,loop)
		self.anims[name].anim.loop = loop
	end,
	
	isPlaying = function(self,name)
		name = name or self.state
		return self.anims[name].playing
	end,
}

return AnimationController