local Player = class {
	init = function(self,x,y)
		self.x = x or 0
		self.y = y or 0
		self.w = 32
		self.h = 32
		self.speed = 100
		
		self.shape = Physics.Rectangle(self.x,self.y,self.w,self.h)
		
		self.sprite = "playerD"
		self.eyeColor = {0,0.4,0,1}
		self.anim = Instance.AnimationController({
			["playerU"]     = require("bin/data/animations/playerU"),
			["playerD"]     = require("bin/data/animations/playerD"),
			["playerL"]     = require("bin/data/animations/playerL"),
			["playerR"]     = require("bin/data/animations/playerR"),
			["playerWalkU"] = require("bin/data/animations/playerUWalk"),
			["playerWalkD"] = require("bin/data/animations/playerDWalk"),
			["playerWalkL"] = require("bin/data/animations/playerLWalk"),
			["playerWalkR"] = require("bin/data/animations/playerRWalk"),
		})
		self.armAnim = Instance.AnimationController({
			["playerArmR"] = require("bin/data/animations/playerArmR"),
			["playerArmWalkR"] = require("bin/data/animations/playerArmWalkR"),
			["playerArmL"] = require("bin/data/animations/playerArmL"),
			["playerArmWalkL"] = require("bin/data/animations/playerArmWalkL"),
		})
		self.direction = "R"
		self.armSprite = "playerArmR1"
		
		self.armOffsets = {
			["playerArmR1"] = {x=8,y=4},
			["playerArmR2"] = {x=8,y=4},
			["playerArmR3"] = {x=2,y=0},
			["playerArmL1"] = {x=10,y=4},
			["playerArmL2"] = {x=10,y=4},
			["playerArmL3"] = {x=16,y=0},
		}
		
		self.anim:playAnimation("playerD")
		self.armAnim:playAnimation("playerArmR")
	end,
	
	update = function(self,dt)
		local mx,my = 0,0
	
		if Keys.UP:isDown() then
			my = my - 1
		end
		
		if Keys.DOWN:isDown() then
			my = my + 1
		end
		
		if Keys.LEFT:isDown() then
			mx = mx - 1
		end
		
		if Keys.RIGHT:isDown() then
			mx = mx + 1
		end
		
		if mx ~= 0 and my ~= 0 then
			local mag = math.sqrt(mx*mx + my*my)
			mx = mx/mag
			my = my/mag
		end
		
		local vx,vy = mx * self.speed * dt,my * self.speed * dt
		
		self.shape:setPosition(self.x + vx,self.y + vy)
		
		self.x = self.shape.x
		self.y = self.shape.y
		
		if my > 0 then
			self.direction = "D"
		elseif my < 0 then
			self.direction = "U"
		end
		
		if mx > 0 then
			self.direction = "R"
		elseif mx < 0 then
			self.direction = "L"
		end
		
		if vx == 0 and vy == 0 then
			self.anim:playAnimation("player"..self.direction)
			
			if self.direction == "L" or self.direction == "R" then
				self.armAnim:playAnimation("playerArm"..self.direction)
			end
		else
			if not self.anim:isPlaying("playerWalk"..self.direction) then
				self.anim:playAnimation("playerWalk"..self.direction)
			end
			
			if self.direction == "L" or self.direction == "R" then
				if not self.armAnim:isPlaying("playerArmWalk"..self.direction) then
					self.armAnim:playAnimation("playerArmWalk"..self.direction)
				end
			end
		end
		
		self.anim:update(dt)
		self.armAnim:update(dt)
		
		self.sprite = self.anim:getCurrentFrame()
		self.armSprite = self.armAnim:getCurrentFrame()
		
		--self.sprite = "playerWalkR2"
		--self.armSprite = "playerArmR3"
	end,
	
	draw = function(self)
		Shaders.eye:sendColor("eyeColor",self.eyeColor)
		love.graphics.setShader(Shaders.eye)
		Texture.draw(self.sprite,self.x,self.y-22,0,16*2,27*2)
		love.graphics.setShader()
		
		if self.direction == "L" or self.direction == "R" then
			local offset = self.armOffsets[self.armSprite]
			Texture.draw(self.armSprite,self.x+offset.x,self.y+offset.y,0,7*2,8*2)
		end
		
		if self.shirt then
			Texture.draw(self.shirt..self.direction,self.x+4,self.y-2,0,12*2,10*2)
		end
	end,
}

return Player