function love.load()
	graphicsInit()
	libInit()
	shadersInit()
	classInit()
	sceneInit()
	keyInit()
	enumInit()
	replacePlayerTextures("character1")
	
	gameDebug = true
	gameSpeed = 1
	gameFrames = 0
	
	setScene("test")
	Scene:init()
end

function love.update(dt)
	dt = dt * gameSpeed
	Scene:update(dt)

	updateTitle()
	updateIcon()
	
	if gameFrames%1000 == 0 then
		print(collectgarbage("count"))
		collectgarbage("collect")
	end
end

function love.draw()
	gameFrames = gameFrames + 1
	--print(gameFrames)
	Scale:push()
	Scene:draw()
	love.graphics.print(tostring(gameFrames),0,0)
	Scale:pop()
end

function love.resize(w,h)
	Scale:resize(w,h)
end

function love.keypressed(key)
	if love.keyboard.isDown("lalt") and key == "return" then
		love.window.setFullscreen(not love.window.getFullscreen())
		love.resize(love.graphics.getDimensions())
	end
end

------------------
--Init Functions--
------------------

function graphicsInit()
	resW = 1280
	resH = 720
	
	love.window.setMode(resW,resH,{resizable = true,vsync = 1})
	love.graphics.setDefaultFilter("nearest","nearest")
	love.graphics.setLineStyle("rough")
	love.graphics.setLineWidth(1)
	
	winTitle = "Untitled"
	winIcon = love.image.newImageData("icon.png")
	updateIcon()
	updateTitle()
	
	Tilesets = {
		Spring = require("bin/data/tilesets/ts_test"),
	}
end

function libInit()
	class = require("bin/lib/clasp")
	const = require("bin/lib/const")
	
	Texture = require("bin/lib/texture")
	Scene = require("bin/lib/scene")
	Scale = require("bin/lib/scale")
	Animation = require("bin/lib/anim")
	
	Texture.include("bin/data/textures")
	Scale:init(resW,resH)
end

function shadersInit()
	Shaders = {
		eye = love.graphics.newShader("bin/shaders/eye.glsl"),
	}
end

function enumInit()
	Enum = {
		Shirts = require("bin/data/enums/shirts"),
	}
end

function replacePlayerTextures(character)
	Texture.replace("playerU",character.."U")
	Texture.replace("playerD",character.."D")
	Texture.replace("playerL",character.."L")
	Texture.replace("playerR",character.."R")
	Texture.replace("playerWalkU1",character.."WalkU1")
	Texture.replace("playerWalkU2",character.."WalkU2")
	Texture.replace("playerWalkD1",character.."WalkD1")
	Texture.replace("playerWalkD2",character.."WalkD2")
	Texture.replace("playerWalkL1",character.."WalkL1")
	Texture.replace("playerWalkL2",character.."WalkL2")
	Texture.replace("playerWalkR1",character.."WalkR1")
	Texture.replace("playerWalkR2",character.."WalkR2")
	Texture.replace("playerArmR1",character.."ArmR1")
	Texture.replace("playerArmR2",character.."ArmR2")
	Texture.replace("playerArmR3",character.."ArmR3")
	Texture.replace("playerArmL1",character.."ArmL1")
	Texture.replace("playerArmL2",character.."ArmL2")
	Texture.replace("playerArmL3",character.."ArmL3")
end

function classInit()
	Color = require("bin/classes/color")
	Key = require("bin/classes/key")
	
	Physics = {
		Rectangle = require("bin/classes/physics/rect2d"),
	}
	
	Instance = {
		Player = require("bin/classes/player"),
		Map = require("bin/classes/tilemap"),
		Camera = require("bin/classes/camera"),
		AnimationController = require("bin/classes/animcontroller"),
	}
end

function sceneInit()
	Scenes = {
		["test"] = "bin/scenes/test",
	}
end

function keyInit()
	Keys = {
		UP    = Key({"w","up"}),
		DOWN  = Key({"s","down"}),
		LEFT  = Key({"a","left"}),
		RIGHT = Key({"d","right"}),
	}
end

-------------
--Functions--
-------------

function updateTitle()
	if gameDebug then
		love.window.setTitle(winTitle.." | ".."FPS:"..tostring(love.timer.getFPS()).." | Delta:"..tostring(math.floor(love.timer.getDelta()*1000)).."ms")
	else
		love.window.setTitle(winTitle)
	end
end

function updateIcon()
	love.window.setIcon(winIcon)
end

function setScene(scenename)
	Scene.loadScene(Scenes[scenename])
end